import { Dispatch, SetStateAction } from 'react';
export { default as Color } from 'color';
export declare type ContentElement = string | JSXChildren;
export interface Coordinator<T> {
    x: T;
    y: T;
}
export declare type JSXChildren = JSX.Element | JSX.Element[];
export interface JSXElementProps {
    [key: string]: any;
}
export declare type Nullable<T> = T | null;
export interface NestedObject<T> {
    [key: string]: T | NestedObject<T>;
}
export declare type PaletteProp = 'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'light' | 'dark' | (string & {});
export declare type Partial<T> = {
    [key in keyof T]?: T[key] extends object ? Partial<T[key]> : T[key];
};
export declare type ResponsiveProp<K extends string, T> = {
    [key in K as K]: T;
} & {
    [key in K as `${K}Sm` | `${K}Md` | `${K}Lg` | `${K}Xl`]?: T;
};
export declare type ResponsiveProps<T> = {
    [key in keyof T as key]?: T[key];
} & {
    [key in keyof T as key extends string ? `${key}Sm` : never]?: T[key];
} & {
    [key in keyof T as key extends string ? `${key}Md` : never]?: T[key];
} & {
    [key in keyof T as key extends string ? `${key}Lg` : never]?: T[key];
} & {
    [key in keyof T as key extends string ? `${key}Xl` : never]?: T[key];
};
export declare type SetState<T> = ((value: T) => void) | Dispatch<SetStateAction<T>>;
export interface Shape<T> {
    rectangle: T;
    rounded: T;
    [key: string]: T;
}
export declare type ShapeProp = 'rectangle' | 'rounded' | (string & {});
export interface Size<T> {
    small: T;
    medium: T;
    large: T;
    [key: string]: T;
}
export declare type SizeProp = 'small' | 'medium' | 'large' | (string & {});
export declare type SizeProps = Partial<ResponsiveProp<'size', SizeProp>>;
export declare type TableStripedOrientation = 'odd' | 'even';
export declare type TimingFunction = 'cubic-bezier()' | 'ease' | 'ease-in' | 'ease-in-out' | 'ease-out' | 'linear' | 'step-end' | 'step-start' | 'steps()' | (string & {});
export declare type Value = string | number;
