"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mix = exports.getFontColor = exports.getColor = void 0;
const color_1 = __importDefault(require("color"));
/**
 * Creates a color object by value.
 */
const getColor = (value) => {
    try {
        return (0, color_1.default)(value);
    }
    catch (err) {
        return null;
    }
};
exports.getColor = getColor;
/**
 * Gets font color by value.
 */
const getFontColor = (value, theme) => (0, exports.getColor)(value).isDark() ? theme.$.color.dark.font : theme.$.color.light.font;
exports.getFontColor = getFontColor;
/**
 * Mixes two colors.
 * If weight is a negative number, mixes value with white.
 * If weight is a positive number, mixes value with black.
 * Weight could be an three-length array. It applies different weight for red, green, and blue respectively.
 */
const mix = (value, weight) => {
    const weightList = typeof weight === 'number' ? [weight, weight, weight] : weight;
    const rgb = [];
    const secondary = (0, exports.getColor)(value).hex().toString();
    for (let i = 0; i < 3; i++) {
        const primary = weightList[i] > 0 ? '#000000' : '#FFFFFF';
        weightList[i] = Math.abs(weightList[i]);
        const startValue = i * 2 + 1;
        const endValue = startValue + 2;
        const valueByPrimary = parseInt(primary.substring(startValue, endValue), 16);
        const valueBySecondary = parseInt(secondary.substring(startValue, endValue), 16);
        let mixedValue = Math.floor(valueByPrimary * weightList[i] + valueBySecondary * (1 - weightList[i])).toString(16);
        if (mixedValue.length === 1) {
            mixedValue = `0${mixedValue}`;
        }
        rgb.push(mixedValue);
    }
    return `#${rgb.join('')}`;
};
exports.mix = mix;
